<?php # $Id: serendipity_lang_bg.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) 2004 Bogomil Shopov <bogomil@spisanie.com>
# http://www.purplerain.org/nb/
# Ognyan Kulev <ogi@fmi.uni-sofia.bg>, 2005
# Ivan Cenov <JWalker@hotmail.bg>, 2005-2006
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'windows-1251');
@define('SQL_CHARSET', 'cp1251');
//@define('DATE_LOCALES', 'bg_BG');
@define('DATE_LOCALES', 'bulgarian, bg, bg_BG');
@define('DATE_FORMAT_ENTRY', '%A, %e %B %Y');
@define('WYSIWYG_LANG', 'en');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', '  Serendipity');
@define('HAVE_TO_BE_LOGGED_ON', '  ,     :');
@define('WRONG_USERNAME_OR_PASSWORD', '     ');
@define('APPEARANCE', '');
@define('MANAGE_STYLES', '  ');
@define('CONFIGURE_PLUGINS', '   ');
@define('CONFIGURATION', '');
@define('BACK_TO_BLOG', '  ');
@define('LOGIN', '');
@define('LOGOUT', '');
@define('LOGGEDOUT', '  .');
@define('CREATE', '');
@define('SAVE', '');
@define('NAME', '');
@define('CREATE_NEW_CAT', '   ');
@define('I_WANT_THUMB', '   .');
@define('I_WANT_BIG_IMAGE', '     ');
@define('I_WANT_NO_LINK', '   ');
@define('I_WANT_IT_TO_LINK', '      :');
@define('BACK', '');
@define('FORWARD', '');
@define('ANONYMOUS', '');
@define('NEW_TRACKBACK_TO', '  ');
@define('NEW_COMMENT_TO', '   ');
@define('RECENT', '...');
@define('OLDER', '-...');
@define('DONE', '');
@define('WELCOME_BACK', '  ,');
@define('TITLE', '');
@define('DESCRIPTION', '');
@define('PLACEMENT', '');
@define('DELETE', '');
@define('SAVE', '');
@define('UP', '');
@define('DOWN', '');
@define('ENTRIES', ':');
@define('NEW_ENTRY', '');
@define('EDIT_ENTRIES', '');
@define('CATEGORIES', '');
@define('WARNING_THIS_BLAHBLAH', "!!!:\\n       ,    .");
@define('CREATE_THUMBS', '  ');
@define('MANAGE_IMAGES', '  ');
@define('NAME', '');
@define('EMAIL', '.');
@define('HOMEPAGE', '  ');
@define('COMMENT', '');
@define('REMEMBER_INFO', '  ? ');
@define('SUBMIT_COMMENT', '  ');
@define('NO_ENTRIES_TO_PRINT', '   ');
@define('COMMENTS', '');
@define('ADD_COMMENT', '  ');
@define('NO_COMMENTS', ' ');
@define('POSTED_BY', ' ');
@define('ON', '');
@define('A_NEW_COMMENT_BLAHBLAH', '        "%s",  "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', '      "%s".');
@define('NO_CATEGORY', ' ');
@define('ENTRY_BODY', '  ');
@define('EXTENDED_BODY', ' ');
@define('CATEGORY', ':');
@define('EDIT', '');
@define('NO_ENTRIES_BLAHBLAH', '    %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', '  %s  %s :');
@define('IMAGE', '');
@define('ERROR_FILE_NOT_EXISTS', ':    !');
@define('ERROR_FILE_EXISTS', ':     ,  !');
@define('ERROR_SOMETHING', ':    .');
@define('ADDING_IMAGE', '  ...');
@define('THUMB_CREATED_DONE', '  .<br/>.');
@define('ERROR_FILE_EXISTS_ALREADY', ':    !');
@define('GO', '');
@define('NEWSIZE', ' : ');
@define('RESIZE_BLAHBLAH', '<b>    %s</b><p>');
@define('ORIGINAL_SIZE', ' : <i>%s&#215;%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>       .      ,          TAB.      ,      .');
@define('QUICKSEARCH', ' ');
@define('SEARCH_FOR_ENTRY', '  ');
@define('ARCHIVES', '');
@define('BROWSE_ARCHIVES', '    ');
@define('TOP_REFERRER', '  ');
@define('SHOWS_TOP_SITES', '        ');
@define('TOP_EXITS', '  ');
@define('SHOWS_TOP_EXIT', '        ');
@define('SYNDICATION', '');
@define('SHOWS_RSS_BLAHBLAH', '    RSS ');
@define('ADVERTISES_BLAHBLAH', '    ');
@define('HTML_NUGGET', '  HTML');
@define('HOLDS_A_BLAHBLAH', '    HTML   ');
@define('TITLE_FOR_NUGGET', '    HTML');
@define('THE_NUGGET', '  HTML!');
@define('SYNDICATE_THIS_BLOG', '    ');
@define('YOU_CHOSE', '  %s');
@define('IMAGE_SIZE', '  ');
@define('IMAGE_AS_A_LINK', '  ');
@define('POWERED_BY', ' ');
@define('TRACKBACKS', '');
@define('TRACKBACK', '');
@define('NO_TRACKBACKS', ' ');
@define('TOPICS_OF', ' ');
@define('VIEW_FULL', ' ');
@define('VIEW_TOPICS', ' ');
@define('AT', '');
@define('SET_AS_TEMPLATE', '  ');
@define('VIEW_EXTENDED_ENTRY', '  ');
@define('IN', '');
@define('EXCERPT', '');
@define('TRACKED', '');
@define('LINK_TO_ENTRY', '  ');
@define('LINK_TO_REMOTE_ENTRY', '   ');
@define('IP_ADDRESS', 'IP-');
@define('USER', '');
@define('THUMBNAIL_USING_OWN', '  %s  ,       .');
@define('THUMBNAIL_FAILED_COPY', '%s      ,      !');
@define('AUTHOR', '');
@define('LAST_UPDATED', ' ');
@define('TRACKBACK_SPECIFIC', 'URI     ');
@define('DIRECT_LINK', '    ');
@define('COMMENT_ADDED', '    . ');
@define('COMMENT_ADDED_CLICK', ' %s,    %s  ,  %s,   %s  .');
@define('COMMENT_NOT_ADDED_CLICK', ' %s,    %s  ,  %s,   %s  .');
@define('COMMENTS_DISABLE', '     ');
@define('COMMENTS_ENABLE', '     ');
@define('COMMENTS_CLOSED', '      ');
@define('EMPTY_COMMENT', '    , , %s %s   ');
@define('ENTRIES_FOR', '  %s');
@define('DOCUMENT_NOT_FOUND', ' %s   .');
@define('USERNAME', '');
@define('PASSWORD', '');
@define('AUTOMATIC_LOGIN', '   .');
@define('SERENDIPITY_INSTALLATION', '  Serendipity');
@define('LEFT', '');
@define('RIGHT', '');
@define('HIDDEN', '');
@define('REMOVE_TICKED_PLUGINS', '   ');
@define('SAVE_CHANGES_TO_LAYOUT', '    ');
@define('COMMENTS_FROM', ' ');
@define('ERROR', '');
@define('ENTRY_SAVED', '  ');
@define('DELETE_SURE', '  ,     #%s ?');
@define('NOT_REALLY', '');
@define('DUMP_IT', '');
@define('RIP_ENTRY', ' &#160;%s  ');
@define('CATEGORY_DELETED', ' &#160;%s  .');
@define('INVALID_CATEGORY', '   ');
@define('CATEGORY_SAVED', '  ');
@define('SELECT_TEMPLATE', '  ,      ');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', '      !');
@define('YES', '');
@define('NO', '');
@define('CHECK_N_SAVE', '  ');
@define('DIRECTORY_WRITE_ERROR', '       %s. ,  .');
@define('DIRECTORY_CREATE_ERROR', ' %s        . ,   ');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; : <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', '      %s.');
@define('FILE_WRITE_ERROR', '       %s');
@define('FILE_CREATE_YOURSELF', ',       ');
@define('COPY_CODE_BELOW', '<br />*     -     %s   %s <b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', ' www   ,     Apache.');
@define('BROWSER_RELOAD', '  ,      .');
@define('DIAGNOSTIC_ERROR', '        :');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity    . , <a href="%s"></a>  .');
@define('INCLUDE_ERROR', '  Serendipity:       %s - .');
@define('DATABASE_ERROR', ' Serendipity:          - .');
@define('CREATE_DATABASE', '      ...');
@define('ATTEMPT_WRITE_FILE', '     %s...');
@define('WRITTEN_N_SAVED', '  ');
@define('IMAGE_ALIGNMENT', '  ');
@define('ENTER_NEW_NAME', '   : ');
@define('RESIZING', '  ');
@define('RESIZE_DONE', ' (    %s ).');
@define('SYNCING', '       ');
@define('SYNC_DONE', ' (  %s ).');
@define('DELETE_FILE_FAIL' , '      <b>%s</b>');
@define('DELETE_THUMBNAIL', '  ,  <b>%s</b>');
@define('FILE_NOT_FOUND', '     ,  <b>%s</b>.     ?');
@define('ABORT_NOW', '   ');
@define('REMOTE_FILE_NOT_FOUND', '      ,   ,   <b>%s</b>  ?');
@define('FILE_FETCHED', '%s    %s');
@define('FILE_UPLOADED', ' %s     %s');
@define('WORD_OR', '');
@define('SCALING_IMAGE', '    %s  %s&#215;%s ');
@define('KEEP_PROPORTIONS', '  ');
@define('REALLY_SCALE_IMAGE', '  ,     ?       !');
@define('TOGGLE_ALL', '  ');
@define('TOGGLE_OPTION', '  ');
@define('SUBSCRIBE_TO_THIS_ENTRY', '   ');
@define('UNSUBSCRIBE_OK', "%s      ");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', '     "%s"');
@define('SUBSCRIPTION_MAIL', " %s,\n\n     ,   \"%s\",  \"%s\"\n: %s\n\n    : %s\n\n   ,    : %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', " %s,\n\n     ,    \"%s\",  \"%s\"\n: %s\n\n    : %s\n\n   ,    : %s\n");
@define('SIGNATURE', "\n-- \n%s    Serendipity.\n- ,      .\n <http://s9y.org>  .");
@define('SYNDICATION_PLUGIN_091', '  RSS 0.91');
@define('SYNDICATION_PLUGIN_10', '  RSS 1.0');
@define('SYNDICATION_PLUGIN_20', '  RSS 2.0');
@define('SYNDICATION_PLUGIN_20c', '  RSS 2.0  ');
@define('SYNDICATION_PLUGIN_ATOM03', '  Atom 0.3');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', ' "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  ' "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', '    RSS');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', '  ');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', '  ');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  '.    (: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', '.   ,   . (: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL     GIF, JPEG  PNG,    (:   Serendipity)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', ' , . 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', ' , . 400');
@define('SYNDICATION_PLUGIN_TTL', ' "ttl" (  )');
@define('SYNDICATION_PLUGIN_TTL_DESC', '             (: ) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', ' "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', '      "pubDate"    RSS,       ?');
@define('CONTENT', '');
@define('TYPE', 'T');
@define('DRAFT', '');
@define('PUBLISH', '');
@define('PREVIEW', ' ');
@define('DATE', '');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', ':     .      : YYYY-MM-DD HH:MM ');
@define('CATEGORY_PLUGIN_DESC', '   .');
@define('ALL_AUTHORS', ' ');
@define('CATEGORIES_TO_FETCH', '  ');
@define('CATEGORIES_TO_FETCH_DESC', '    ?');
@define('PREVIOUS_PAGE', ' ');
@define('NEXT_PAGE', ' ');
@define('ALL_CATEGORIES', ' ');
@define('DO_MARKUP', '    markup');
@define('GENERAL_PLUGIN_DATEFORMAT', '  ');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', '     ,      PHP strftime() (: "%s")');
@define('ERROR_TEMPLATE_FILE', '      , ,  Serendipity!');
@define('ADVANCED_OPTIONS', ' ');
@define('EDIT_ENTRY', '  ');
@define('HTACCESS_ERROR', '        , serendipity        ".htaccess".        . ,      : <br />&nbsp;&nbsp;%s<br />    .');
@define('SIDEBAR_PLUGINS', ' ');
@define('EVENT_PLUGINS', ' ');
@define('SORT_ORDER', ' ');
@define('SORT_ORDER_NAME', '  ');
@define('SORT_ORDER_EXTENSION', '');
@define('SORT_ORDER_SIZE', '  ');
@define('SORT_ORDER_WIDTH', '  ');
@define('SORT_ORDER_HEIGHT', '  ');
@define('SORT_ORDER_DATE', '  ');
@define('SORT_ORDER_ASC', '');
@define('SORT_ORDER_DESC', '');
@define('THUMBNAIL_SHORT', '');
@define('ORIGINAL_SHORT', '.');
@define('APPLY_MARKUP_TO', '  markup  %s');
@define('CALENDAR_BEGINNING_OF_WEEK', '  ');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity ,      Serendipity  %s.         %s,   <a href="%s"> </a>,       ');
@define('SERENDIPITY_UPGRADER_WELCOME', ',         Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', ' ,       Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', '   ,  -  Serendipity %s,          ');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', '    (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', '   .sql ,     ,        Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  '    ');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', '       ');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', '     ?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', ',     ');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', ', ');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', '      ');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', ' Serendipity  ');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', '    Serendipity. ,  ,           ');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', '   Serendipity      %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', '         %s%s');
@define('TRACKBACK_COULD_NOT_CONNECT', '   :        %s   %d');
@define('MEDIA', '');
@define('MEDIA_LIBRARY', ' ');
@define('ADD_MEDIA', '  ');
@define('ENTER_MEDIA_URL', ' URL    :');
@define('ENTER_MEDIA_UPLOAD', ' ,    :');
@define('SAVE_FILE_AS', '   :');
@define('STORE_IN_DIRECTORY', '   : ');
@define('MEDIA_RENAME', '   ');
@define('IMAGE_RESIZE', '     ');
@define('MEDIA_DELETE', '   ');
@define('FILES_PER_PAGE', '  ');
@define('CLICK_FILE_TO_INSERT', ' ,    :');
@define('SELECT_FILE', '   ');
@define('MEDIA_FULLSIZE', ' ');
@define('CALENDAR_BOW_DESC', '  ,        .    ');
@define('SUPERUSER', '  ');
@define('ALLOWS_YOU_BLAHBLAH', '        ');
@define('CALENDAR', '');
@define('QUICKJUMP_CALENDAR', '    ');
@define('SUPERUSER_OPEN_ADMIN', '');
@define('SUPERUSER_OPEN_LOGIN', '  ');
@define('INVERT_SELECTIONS', '  ');
@define('COMMENTS_DELETE_CONFIRM', '  ,      ?');
@define('COMMENT_DELETE_CONFIRM', '  ,      &#160;%d,   %s?');
@define('DELETE_SELECTED_COMMENTS', '   ');
@define('VIEW_COMMENT', '  ');
@define('VIEW_ENTRY', '  ');
@define('DELETE_FILE', '  ,  <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', '     <b>%s</b><br />        ,        <br />  ,    ?<br /><br />');
@define('TRACKBACK_SENDING', '    URI- %s...');
@define('TRACKBACK_SENT', '  ');
@define('TRACKBACK_FAILED', '  : %s');
@define('TRACKBACK_NOT_FOUND', '   URI  .');
@define('TRACKBACK_URI_MISMATCH', '    URI      URI.');
@define('TRACKBACK_CHECKING', '  <u>%s</u>   ...');
@define('TRACKBACK_NO_DATA', '   ');
@define('TRACKBACK_SIZE', ' URI       %s .');
@define('VIEWMODE_THREADED', '   ');
@define('COMMENTS_VIEWMODE_THREADED', '');
@define('COMMENTS_VIEWMODE_LINEAR', '');
@define('DISPLAY_COMMENTS_AS', '  :');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '&#160;');
@define('ERROR_UNKNOWN_NOUPLOAD', '       .       -       .        php.ini,     - .');
@define('CATEGORY_DELETED_ARTICLES_MOVED', ' &#160;%s  .       &#160;%s');
@define('USE_DEFAULT', ' ');
@define('PAGE_BROWSE_ENTRIES', ' %s  %s,  %s ');
@define('MANAGE_USERS', '  ');
@define('CREATE_NEW_USER', '   ');
@define('CREATE_NOT_AUTHORIZED', '           ');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', '      -    ');
@define('CREATED_USER', '    %s');
@define('MODIFIED_USER', '   %s  ');
@define('USER_LEVEL', ' ');
@define('DELETE_USER', '     &#160;%%d %s.   ?       ,   ,     .');
@define('DELETED_USER', ' &#160;%d %s  .');
@define('LIMIT_TO_NUMBER', '    ?');
@define('ENTRIES_PER_PAGE', '  ');
@define('XML_IMAGE_TO_DISPLAY', '  XML');
@define('DIRECTORIES_AVAILABLE', '            ,        .');
@define('ALL_DIRECTORIES', ' ');
@define('MANAGE_DIRECTORIES', '  ');
@define('DIRECTORY_CREATED', '   <strong>%s</strong>.');
@define('PARENT_DIRECTORY', '- ');
@define('CONFIRM_DELETE_DIRECTORY', '  ,         %s?');
@define('ERROR_NO_DIRECTORY', ':  %s  ');
@define('CHECKING_DIRECTORY', '     %s');
@define('DELETING_FILE', '   %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', '      .   " ",      ,    .   :');
@define('DIRECTORY_DELETE_FAILED', '     %s.     -.');
@define('DIRECTORY_DELETE_SUCCESS', ' %s   .');
@define('SKIPPING_FILE_EXTENSION', '  :    %s.');
@define('SKIPPING_FILE_UNREADABLE', '  : %s     .');
@define('FOUND_FILE', '     : %s.');
@define('ALREADY_SUBCATEGORY', '%s     %s.');
@define('PARENT_CATEGORY', '- ');
@define('IN_REPLY_TO', '  ');
@define('TOP_LEVEL', '');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', ' %s');
@define('PERMISSIONS', '');
@define('SETTINGS_SAVED_AT', '     %s');
@define('INSTALL_CAT_DB', '   ');
@define('INSTALL_CAT_DB_DESC', '        . Serendipity    ,     ');
@define('INSTALL_DBTYPE', '');
@define('INSTALL_DBTYPE_DESC', '   ');
@define('INSTALL_DBHOST', '');
@define('INSTALL_DBHOST_DESC', '  ,      ');
@define('INSTALL_DBUSER', '');
@define('INSTALL_DBUSER_DESC', '  ,          ');
@define('INSTALL_DBPASS', '');
@define('INSTALL_DBPASS_DESC', '   ');
@define('INSTALL_DBNAME', '   ');
@define('INSTALL_DBNAME_DESC', '    ');
@define('INSTALL_DBPREFIX', '  ');
@define('INSTALL_DBPREFIX_DESC', '    , . serendipity_');
@define('INSTALL_CAT_PATHS', '');
@define('INSTALL_CAT_PATHS_DESC', '       .        !');
@define('INSTALL_FULLPATH', ' ');
@define('INSTALL_FULLPATH_DESC', '        Serendipity');
@define('INSTALL_UPLOADPATH', '  ');
@define('INSTALL_UPLOADPATH_DESC', '      ,  " " -  "uploads"');
@define('INSTALL_RELPATH', ' ');
@define('INSTALL_RELPATH_DESC', '  Serendipity  ,  "/serendipity/"');
@define('INSTALL_RELTEMPLPATH', '   ');
@define('INSTALL_RELTEMPLPATH_DESC', '     -  " "');
@define('INSTALL_RELUPLOADPATH', '   ');
@define('INSTALL_RELUPLOADPATH_DESC', '       -  " "');
@define('INSTALL_URL', 'URL  ');
@define('INSTALL_URL_DESC', ' URL     Serendipity');
@define('INSTALL_INDEXFILE', ' ');
@define('INSTALL_INDEXFILE_DESC', '      Serendipity');
@define('INSTALL_CAT_SETTINGS', ' ');
@define('INSTALL_CAT_SETTINGS_DESC', '    Serendipity');
@define('INSTALL_USERNAME', ' ');
@define('INSTALL_USERNAME_DESC', '   ');
@define('INSTALL_PASSWORD', ' ');
@define('INSTALL_PASSWORD_DESC', '  ');
@define('INSTALL_EMAIL', '.   ');
@define('INSTALL_EMAIL_DESC', '.     ');
@define('INSTALL_SENDMAIL', '    ?');
@define('INSTALL_SENDMAIL_DESC', '    ,       ?');
@define('INSTALL_SUBSCRIBE', '      ?');
@define('INSTALL_SUBSCRIBE_DESC', '             ,       ');
@define('INSTALL_BLOGNAME', '  ');
@define('INSTALL_BLOGNAME_DESC', '   ');
@define('INSTALL_BLOGDESC', '  ');
@define('INSTALL_BLOGDESC_DESC', '   ');
@define('INSTALL_LANG', '');
@define('INSTALL_LANG_DESC', '    ');
@define('INSTALL_CAT_DISPLAY', '  ');
@define('INSTALL_CAT_DISPLAY_DESC', '    Serendipity');
@define('INSTALL_WYSIWYG', '   WYSIWYG');
@define('INSTALL_WYSIWYG_DESC', '     WYSIWYG? (  IE5+,   Mozilla 1.3+)');
@define('INSTALL_POPUP', '     ');
@define('INSTALL_POPUP_DESC', '       ,   .?');
@define('INSTALL_EMBED', '   Serendipity?');
@define('INSTALL_EMBED_DESC', '    Serendipity   ,          ,   .     indexFile,     ,       .   README   !');
@define('INSTALL_TOP_AS_LINKS', '        ?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"":         ,      Google. "":        . "":     ().');
@define('INSTALL_BLOCKREF', '  ');
@define('INSTALL_BLOCKREF_DESC', '   ,           ?          ";"  ,        !');
@define('INSTALL_REWRITE', '  URL');
@define('INSTALL_REWRITE_DESC', '         URL-.       URL-        -   Google   .       mod_rewrite,  "AllowOverride All"     Serendipity.            ');
@define('INSTALL_CAT_IMAGECONV', '    ');
@define('INSTALL_CAT_IMAGECONV_DESC', '     Serendipity   ');
@define('INSTALL_IMAGEMAGICK', '  Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', '  instaliran image magick            ?');
@define('INSTALL_IMAGEMAGICKPATH', '    convert');
@define('INSTALL_IMAGEMAGICKPATH_DESC', '       convert  image magick');
@define('INSTALL_THUMBSUFFIX', '  ');
@define('INSTALL_THUMBSUFFIX_DESC', '      : .[].');
@define('INSTALL_THUMBWIDTH', '  ');
@define('INSTALL_THUMBWIDTH_DESC', '      ');
@define('USERCONF_CAT_PERSONAL', ' ');
@define('USERCONF_CAT_PERSONAL_DESC', '    ');
@define('USERCONF_USERNAME', ' ');
@define('USERCONF_USERNAME_DESC', ' ,      ');
@define('USERCONF_PASSWORD', '');
@define('USERCONF_PASSWORD_DESC', ',        ');
@define('USERCONF_EMAIL', '. ');
@define('USERCONF_EMAIL_DESC', '  . ');
@define('USERCONF_SENDCOMMENTS', '    ?');
@define('USERCONF_SENDCOMMENTS_DESC', '             ?');
@define('USERCONF_SENDTRACKBACKS', '  ?');
@define('USERCONF_SENDTRACKBACKS_DESC', '           ?');
@define('USERCONF_ALLOWPUBLISH', ':   ?');
@define('USERCONF_ALLOWPUBLISH_DESC', '        ?');
@define('SUCCESS', '');
@define('POWERED_BY_SHOW_TEXT', '  "Serendipity"  ');
@define('POWERED_BY_SHOW_TEXT_DESC', '  "Serendipity Weblog"  ');
@define('POWERED_BY_SHOW_IMAGE', '  "Serendipity"  ');
@define('POWERED_BY_SHOW_IMAGE_DESC', '    Serendipity');
@define('PLUGIN_ITEM_DISPLAY', '     ?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', '   ');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', '  ');
@define('PLUGIN_ITEM_DISPLAY_BOTH', '');
@define('RSS_IMPORT_CATEGORY', '       ');
@define('COMMENTS_WILL_BE_MODERATED', '          .');
@define('YOU_HAVE_THESE_OPTIONS', '    :');
@define('THIS_COMMENT_NEEDS_REVIEW', ':          ');
@define('DELETE_COMMENT', '  ');
@define('APPROVE_COMMENT', '  ');
@define('REQUIRES_REVIEW', '  ');
@define('COMMENT_APPROVED', ' &#160;%s   ');
@define('COMMENT_DELETED', ' &#160;%s   ');
@define('COMMENTS_MODERATE', '       ');
@define('THIS_TRACKBACK_NEEDS_REVIEW', ':        ');
@define('DELETE_TRACKBACK', '  ');
@define('APPROVE_TRACKBACK', '  ');
@define('TRACKBACK_APPROVED', ' &#160;%s   ');
@define('TRACKBACK_DELETED', ' &#160;%s   ');
@define('VIEW', '');
@define('COMMENT_ALREADY_APPROVED', ' &#160;%s    ');
@define('COMMENT_EDITED', '   ');
@define('HIDE', '');
@define('TRACKBACK_SPECIFIC_ON_CLICK', '     .   URI     .     URI,      (ping)         .    ,       "Copy Shortcut"  Internet Explorer  "Copy Link Location"  Mozilla.');
@define('PLUGIN_SUPERUSER_HTTPS', '  https  ');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', '         https.      !');
@define('INSTALL_SHOW_EXTERNAL_LINKS', '   ?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"":    (    ,    )           ,   ,       Google (). "":        .         !');
@define('PAGE_BROWSE_COMMENTS', ' %s  %s,  %s ');
@define('FILTERS', '');
@define('FIND_ENTRIES', '  ');
@define('FIND_COMMENTS', '  ');
@define('FIND_MEDIA', '  ');
@define('FILTER_DIRECTORY', '');
@define('SORT_BY', ' ');
@define('ADD_MEDIA_BLAHBLAH', '<b>      :</b><p>            ,    !    , <a href="http://images.google.com" target="_blank">   Google</a>,     .       :)</p><p><b> :</b></p><br/>');
@define('XML_IMAGE_TO_DISPLAY_DESC', '    XML      .     ,  "none"  .');
@define('COMMENTS_FILTER_SHOW', '');
@define('COMMENTS_FILTER_ALL', '');
@define('COMMENTS_FILTER_APPROVED_ONLY', ' ');
@define('COMMENTS_FILTER_NEED_APPROVAL', ' ');
@define('RSS_IMPORT_BODYONLY', '             .');
@define('SYNDICATION_PLUGIN_FULLFEED', '          RSS');
@define('MT_DATA_FILE', '    Movable Type');
@define('FORCE', '');
@define('CREATE_AUTHOR', '   "%s".');
@define('CREATE_CATEGORY', '   "%s".');
@define('MYSQL_REQUIRED', '      MySQL,     .');
@define('COULDNT_CONNECT', '          MySQL: %s.');
@define('COULDNT_SELECT_DB', '      : %s.');
@define('COULDNT_SELECT_USER_INFO', '       : %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', '       : %s.');
@define('COULDNT_SELECT_ENTRY_INFO', '       : %s.');
@define('COULDNT_SELECT_COMMENT_INFO', '       : %s.');
@define('WEEK', '');
@define('WEEKS', '');
@define('MONTHS', '');
@define('DAYS', '');
@define('ARCHIVE_FREQUENCY', ' ');
@define('ARCHIVE_FREQUENCY_DESC', '  ,        ');
@define('ARCHIVE_COUNT', '    ');
@define('ARCHIVE_COUNT_DESC', '   ,   ,    ');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', '   ');
@define('SIDEBAR_PLUGIN', ' ');
@define('EVENT_PLUGIN', ' ');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', '      %s');
@define('VERSION', '');
@define('INSTALL', '');
@define('ALREADY_INSTALLED', '  ');
@define('SELECT_A_PLUGIN_TO_ADD', ' ,    ');
@define('INSTALL_OFFSET', '   ');
@define('STICKY_POSTINGS', ' ');
@define('INSTALL_FETCHLIMIT', '     ');
@define('INSTALL_FETCHLIMIT_DESC', '  ,         ');
@define('IMPORT_ENTRIES', '  ');
@define('EXPORT_ENTRIES', '  ');
@define('IMPORT_WELCOME', '       Serendipity');
@define('IMPORT_WHAT_CAN', '         ');
@define('IMPORT_SELECT', ',  ,     ');
@define('IMPORT_PLEASE_ENTER', ',    -');
@define('IMPORT_NOW', ' !');
@define('IMPORT_STARTING', '    ...');
@define('IMPORT_FAILED', '  ');
@define('IMPORT_DONE', '  ');
@define('IMPORT_WEBLOG_APP', '  ');
@define('EXPORT_FEED', '     RSS');
@define('STATUS', '  ');
@define('IMPORT_GENERIC_RSS', '   RSS');
@define('ACTIVATE_AUTODISCOVERY', '    ,   ');
@define('WELCOME_TO_ADMIN', '      Serendipity.');
@define('PLEASE_ENTER_CREDENTIALS', ',    -.');
@define('ADMIN_FOOTER_POWERED_BY', '  Serendipity %s  PHP %s');
@define('INSTALL_USEGZIP', '   gzip  ');
@define('INSTALL_USEGZIP_DESC', '     ,         ,    .   .');
@define('INSTALL_SHOWFUTURE', '    ');
@define('INSTALL_SHOWFUTURE_DESC', '  ,         .                .');
@define('INSTALL_DBPERSISTENT', '   ');
@define('INSTALL_DBPERSISTENT_DESC', '        .   <a href="http://php.net/manual/features.persistent-connections.php" target="_blank"></a>.     ');
@define('NO_IMAGES_FOUND', '   ');
@define('PERSONAL_SETTINGS', ' ');
@define('REFERER', ' ');
@define('NOT_FOUND', '  ');
@define('NOT_WRITABLE', '    ');
@define('WRITABLE', '   ');
@define('PROBLEM_DIAGNOSTIC', ' ,   ,            ');
@define('SELECT_INSTALLATION_TYPE', '    ');
@define('WELCOME_TO_INSTALLATION', '     Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', '                 ');
@define('ERRORS_ARE_DISPLAYED_IN', '    %s,   %s    %s');
@define('RED', '');
@define('YELLOW', '');
@define('GREEN', '');
@define('PRE_INSTALLATION_REPORT', '     Serendipity v%s');
@define('RECOMMENDED', '');
@define('ACTUAL', '');
@define('PHPINI_CONFIGURATION', '  php.ini');
@define('PHP_INSTALLATION', '  PHP');
@define('THEY_DO', '');
@define('THEY_DONT', ' ');
@define('SIMPLE_INSTALLATION', ' ');
@define('EXPERT_INSTALLATION', ' ');
@define('COMPLETE_INSTALLATION', ' ');
@define('WONT_INSTALL_DB_AGAIN', '      ');
@define('CHECK_DATABASE_EXISTS', '       ');
@define('CREATING_PRIMARY_AUTHOR', '    "%s"');
@define('SETTING_DEFAULT_TEMPLATE', '    ');
@define('INSTALLING_DEFAULT_PLUGINS', '   ');
@define('SERENDIPITY_INSTALLED', 'Serendipity   ');
@define('VISIT_BLOG_HERE', '    ');
@define('THANK_YOU_FOR_CHOOSING', ' ,   Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', '    ');
@define('OPERATING_SYSTEM', ' ');
@define('WEBSERVER_SAPI', 'SAPI  ');
@define('IMAGE_ROTATE_LEFT', '    90     ');
@define('IMAGE_ROTATE_RIGHT', '    90    ');
@define('TEMPLATE_SET', '\'%s\'     ');
@define('SEARCH_ERROR', '      .      :          .   MySQL,           ,     :: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre>  ,    , : <pre>%s</pre>');
@define('EDIT_THIS_CAT', '  "%s"');
@define('CATEGORY_REMAINING', '           ');
@define('CATEGORY_INDEX', '-    ,    ');
@define('NO_CATEGORIES', ' ');
@define('RESET_DATE', '  ');
@define('RESET_DATE_DESC', '        ');
@define('PROBLEM_PERMISSIONS_HOWTO', '           : `<em>%s</em>`,        FTP');
@define('WARNING_TEMPLATE_DEPRECATED', ':       .    ,   .');
@define('ENTRY_PUBLISHED_FUTURE', '     .');
@define('ENTRIES_BY', '  %s');
@define('PREVIOUS', '');
@define('NEXT', '');
@define('APPROVE', '');
@define('DO_MARKUP_DESCRIPTION', '       (,    *, /, _, ...).         HTML  .');
@define('CATEGORY_ALREADY_EXIST', '   "%s"  ');
@define('IMPORT_NOTES', ':');
@define('ERROR_FILE_FORBIDDEN', '        ');
@define('ADMIN', '');
@define('ADMIN_FRONTPAGE', '');
@define('QUOTE', '');
@define('IFRAME_SAVE', ' Serendipity   ,    ,   ,   XML-RPC.      ..');
@define('IFRAME_SAVE_DRAFT', '     ');
@define('IFRAME_PREVIEW', 'Serendipity       ...');
@define('IFRAME_WARNING', '     IFRAME. ,    serendipity_config.inc.php    $serendipity[\'use_iframe\']   FALSE.');
@define('NONE', '');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', '    ');
@define('UPGRADE', '');
@define('UPGRADE_TO_VERSION', '   %s');
@define('DELETE_DIRECTORY', '  ');
@define('DELETE_DIRECTORY_DESC', '     ,    ,      .');
@define('FORCE_DELETE', '      ,    Serendipity');
@define('CREATE_DIRECTORY', '  ');
@define('CREATE_NEW_DIRECTORY', '   ');
@define('CREATE_DIRECTORY_DESC', '          .      ,    ,     .');
@define('BASE_DIRECTORY', ' ');
@define('USERLEVEL_EDITOR_DESC', ' ');
@define('USERLEVEL_CHIEF_DESC', ' ');
@define('USERLEVEL_ADMIN_DESC', '');
@define('USERCONF_USERLEVEL', '  ');
@define('USERCONF_USERLEVEL_DESC', '          ');
@define('USER_SELF_INFO', '   %s (%s)');
@define('ADMIN_ENTRIES', '');
@define('RECHECK_INSTALLATION', '   ');
@define('IMAGICK_EXEC_ERROR', '    : "%s", : %s,  : %d');
@define('INSTALL_OFFSET_DESC', '       (: %clock%)    ');
@define('UNMET_REQUIREMENTS', ' : %s');
@define('CHARSET', '');
@define('AUTOLANG', '       ');
@define('AUTOLANG_DESC', '  ,          ,              .');
@define('INSTALL_AUTODETECT_URL', '    HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', '  "", Serendipity   ,     HTTP Host      BaseURL.               Serendipity         ,    .');
@define('CONVERT_HTMLENTITIES', '       HTML?');
@define('EMPTY_SETTING', '     "%s"!');
@define('USERCONF_REALNAME', ' ');
@define('USERCONF_REALNAME_DESC', '   .       ');
@define('HOTLINK_DONE', '   .<br />.');
@define('ENTER_MEDIA_URL_METHOD', '  :');
@define('ADD_MEDIA_BLAHBLAH_NOTE', ':      ,  ,              .       ,     .');
@define('MEDIA_HOTLINKED', ' ');
@define('FETCH_METHOD_IMAGE', '     ');
@define('FETCH_METHOD_HOTLINK', '    ');
@define('DELETE_HOTLINK_FILE', '    ,  <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', '  .?');
@define('IMAGE_MORE_INPUT', '   ');
@define('BACKEND_TITLE', '       ');
@define('BACKEND_TITLE_FOR_NUGGET', '     ,                  HTML.      HTML   ,         .');
@define('CATEGORIES_ALLOW_SELECT', '       ?');
@define('CATEGORIES_ALLOW_SELECT_DESC', '    ,           .           ,     .');
@define('PAGE_BROWSE_PLUGINS', ' %s  %s,  %s .');
@define('INSTALL_CAT_PERMALINKS', ' ');
@define('INSTALL_CAT_PERMALINKS_DESC', '     URL-         .       ;  ,       %id%   ,    Serendipity           URL-.');
@define('INSTALL_PERMALINK', '     ');
@define('INSTALL_PERMALINK_DESC', '       URL   URL,    .     %id%, %title%, %day%, %month%, %year%    .');
@define('INSTALL_PERMALINK_AUTHOR', '     ');
@define('INSTALL_PERMALINK_AUTHOR_DESC', '       URL   URL,       .     %id%, %realname%, %username%, %email%    .');
@define('INSTALL_PERMALINK_CATEGORY', '     ');
@define('INSTALL_PERMALINK_CATEGORY_DESC', '       URL   URL,       .     %id%, %name%, %description%    .');
@define('INSTALL_PERMALINK_FEEDCATEGORY', '       RSS');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', '       URL   URL,       .     %id%, %name%, %description%    .');
@define('INSTALL_PERMALINK_ARCHIVESPATH', '  ');
@define('INSTALL_PERMALINK_ARCHIVEPATH', '  ');
@define('INSTALL_PERMALINK_CATEGORIESPATH', '  ');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', '     ');
@define('INSTALL_PERMALINK_DELETEPATH', '    ');
@define('INSTALL_PERMALINK_APPROVEPATH', '    ');
@define('INSTALL_PERMALINK_FEEDSPATH', '    RSS');
@define('INSTALL_PERMALINK_PLUGINPATH', '   ');
@define('INSTALL_PERMALINK_ADMINPATH', '  ');
@define('INSTALL_PERMALINK_SEARCHPATH', '  ');
@define('USERCONF_CREATE', '    ?');
@define('USERCONF_CREATE_DESC', '  ,       ');
@define('INSTALL_CAL', ' ');
@define('INSTALL_CAL_DESC', '      ');
@define('REPLY', '');
@define('USERCONF_GROUPS', '  ');
@define('USERCONF_GROUPS_DESC', '      .    .');
@define('MANAGE_GROUPS', '  ');
@define('DELETED_GROUP', ' &#160;%d %s  .');
@define('CREATED_GROUP', '    %s');
@define('MODIFIED_GROUP', '   %s  ');
@define('GROUP', '');
@define('CREATE_NEW_GROUP', '   ');
@define('DELETE_GROUP', '      &#160;%d %s.   ?');
@define('USERLEVEL_OBSOLETE', ':              .          !');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', '  FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', '  ,    ');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', '  FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', '  ,     (    ),   feedburner.com, : fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', '  FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', ' ( ),       ');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', '    FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', ' ( ),          ');
@define('SEARCH_TOO_SHORT', '        3 .      *  - ,  s9y*,       - .');
@define('INSTALL_DBPORT', '   ');
@define('INSTALL_DBPORT_DESC', ',             ');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', ' :  ');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', ' : ');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', ' :  ');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', ' : ');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', ' :  ');
@define('PLUGIN_GROUP_BACKEND_EDITOR', ' : ');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', ' :   ');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', ' : ');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', ' : ');
@define('PLUGIN_GROUP_BACKEND_FEATURES', ' : ');
@define('PLUGIN_GROUP_IMAGES', '');
@define('PLUGIN_GROUP_ANTISPAM', '');
@define('PLUGIN_GROUP_MARKUP', '');
@define('PLUGIN_GROUP_STATISTICS', '');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration:    ');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel:    ');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate:   "    "');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish:       ');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration:    ');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration:     ');
@define('PERMISSION_ADMINENTRIES', 'adminEntries:   ');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers:      ');
@define('PERMISSION_ADMINIMPORT', 'adminImport:   ');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories:   ');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers:      ');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete:   ');
@define('PERMISSION_ADMINUSERS', 'adminUsers:   ');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete:   ');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel:    ');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame:   ,       ');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers:   ,        ');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew:    ');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups:    ');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins:   ');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers:      ');
@define('PERMISSION_ADMINIMAGES', 'adminImages:    ');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories:    ');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd:    ');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete:    ');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers:       ');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView:    ');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync:   ');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments:   ');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates:   ');
@define('INSTALL_BLOG_EMAIL', '   ');
@define('INSTALL_BLOG_EMAIL_DESC', '   ,       "From"   .  ,   ,      ,    -         From.');
@define('CATEGORIES_PARENT_BASE', '     -...');
@define('CATEGORIES_PARENT_BASE_DESC', '    ,        .');
@define('CATEGORIES_HIDE_PARALLEL', '  ,        ');
@define('CATEGORIES_HIDE_PARALLEL_DESC', '    ,       ,     .    -,        ,   "/  ".');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers:       ');
@define('CHARSET_NATIVE', '');
@define('INSTALL_CHARSET', '    ');
@define('INSTALL_CHARSET_DESC', '       (ISO, EUC, ...)  UTF-8.       UTF-8    ""    .   UTF-8   .    ,        -       .          http://www.s9y.org/index.php?node=46.');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', '  API    ');
@define('CALENDAR_EXTEVENT_DESC', '  ,               .      ,    ,     .');
@define('XMLRPC_NO_LONGER_BUNDLED', ' XML-RPC  Serendipity      Serendipity     ,       .      XML-RPC,    XML-RPC. URL-         -           API-.');
@define('PERM_READ', '  ');
@define('PERM_WRITE', '  ');

@define('PERM_DENIED', ' .');
@define('INSTALL_ACL', '      ');
@define('INSTALL_ACL_DESC', '  ,    ,   ,      ,    .   ,        ,          .           ,   .');
@define('PLUGIN_API_VALIDATE_ERROR', '       "%s".      "%s".');
@define('USERCONF_CHECK_PASSWORD', ' ');
@define('USERCONF_CHECK_PASSWORD_DESC', '     ,        .');
@define('USERCONF_CHECK_PASSWORD_ERROR', '              .     .');
@define('ERROR_XSRF', '      Referrer  HTTP.          /,       (Cross Site Request Forgery - XSRF),   . ,   ,     .');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', '       URL   URL,      RSS   .     %id%, %realname%, %username%, %email%    .');
@define('INSTALL_PERMALINK_FEEDAUTHOR', '       RSS  ');
@define('INSTALL_PERMALINK_AUTHORSPATH', '  ');
@define('AUTHORS', '');
@define('AUTHORS_ALLOW_SELECT', '       ?');
@define('AUTHORS_ALLOW_SELECT_DESC', '    ,           .           ,     .');
@define('AUTHOR_PLUGIN_DESC', '    ');
@define('CATEGORY_PLUGIN_TEMPLATE', '   Smarty?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', '    ,       Smary      .   ,        "plugin_categories.tpl".        ,       ,   .');
@define('CATEGORY_PLUGIN_SHOWCOUNT', '      ?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', '        ?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', '    ,               .');
@define('CUSTOM_ADMIN_INTERFACE', '   ,    ');

@define('COMMENT_NOT_ADDED', '    ,                   - .');
@define('INSTALL_TRACKREF', '     ?');
@define('INSTALL_TRACKREF_DESC', '                .      (),       ,  .');
@define('CATEGORIES_HIDE_PARENT', '     ?');
@define('CATEGORIES_HIDE_PARENT_DESC', '        ,       .    ,      .');
@define('WARNING_NO_GROUPS_SELECTED', ':       ,    .             ,     ,   .          .');
@define('ONTHEFLYSYNCH', '     ');
@define('ONTHEFLYSYNCH_DESC', '  , Serendipity       ,             .');
@define('INSTALL_RSSFETCHLIMIT', '       RSS ');
@define('INSTALL_RSSFETCHLIMIT_DESC', '  ,         RSS .');
@define('INSTAL_DB_UTF8', '        MySQL  ');
@define('INSTAL_DB_UTF8_DESC', '  MySQL.  \'\'  \'SET NAMES\',         .     ,      .');
@define('USERCONF_CHECK_USERNAME_ERROR', '       .');
@define('FURTHER_LINKS', '');
@define('FURTHER_LINKS_S9Y', '   Serendipity');
@define('FURTHER_LINKS_S9Y_DOCS', '  Serendipity');
@define('FURTHER_LINKS_S9Y_BLOG', ' ');
@define('FURTHER_LINKS_S9Y_FORUMS', '');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(  )');

@define('CURRENT_AUTHOR', ' ');

@define('WORD_NEW', '');
@define('SHOW_MEDIA_TOOLBAR', '            ?');
@define('MEDIA_KEYWORDS', '    ');
@define('MEDIA_KEYWORDS_DESC', '   ,   \';\',            .');
@define('MEDIA_EXIF', '  EXIF/JPEG   ');
@define('MEDIA_EXIF_DESC', '  ,  EXIF/JPEG           .           .');
@define('MEDIA_PROP', '   ');

@define('GO_ADD_PROPERTIES', '    ');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', ' ');
@define('MEDIA_PROPERTY_COMMENT2', ' ');
@define('MEDIA_PROPERTY_TITLE', '');
@define('MEDIA_PROP_DESC', '   ,   \';\',        .');
@define('MEDIA_PROP_MULTIDESC', '(   ":MULTI"       ,          )');

@define('STYLE_OPTIONS_NONE', '    .          ,     www.s9y.org  "Configuration of Theme options".');
@define('STYLE_OPTIONS', '  ');

@define('PLUGIN_AVAILABLE_COUNT', ': %d .');

@define('MEDIA_PROPERTY_DATE', ' ');
@define('MEDIA_PROPERTY_RUN_LENGTH', ' (    )');
@define('SYNDICATION_RFC2616', '     RFC2616 RSS-');
@define('SYNDICATION_RFC2616_DESC', '  RFC2616 ,    GET   Serendipity   ,      .    \'\'          ,          .     Planet ,  .    ,      RFC2616.  ,      \'\',     RFC2616,     RSS           ().              Planet,          .       ,    .  : https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
@define('FILENAME_REASSIGNED', '     : %s');
@define('MEDIA_UPLOAD_SIZE', '     ');
@define('MEDIA_UPLOAD_SIZE_DESC', '       .         .  PHP.ini: upload_max_filesize, post_max_size, max_input_time     .           .');
@define('MEDIA_UPLOAD_SIZEERROR', ':     , -  %s !');
@define('MEDIA_UPLOAD_MAXWIDTH', '     ');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', '       ,    .');
@define('MEDIA_UPLOAD_MAXHEIGHT', '     ');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', '      ,    .');
@define('MEDIA_UPLOAD_DIMERROR', ':     , -  %s x %s .');

@define('MEDIA_TARGET', ' (target)   ');
@define('MEDIA_TARGET_JS', '  ( JavaScript,   )');
@define('MEDIA_ENTRY', ' ');
@define('MEDIA_TARGET_BLANK', '  ( target=_blank)');

@define('MEDIA_DYN_RESIZE', '        ?');
@define('MEDIA_DYN_RESIZE_DESC', '  ,                GET.             .');

@define('MEDIA_DIRECTORY_MOVED', '       %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', '       %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', ' -MySQL  ,        URL      URL (  )   .      ,     URL.           ,   ,       .');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'URL       %s .');
@define('PLUGIN_ACTIVE', '');
@define('PLUGIN_INACTIVE', '');
@define('PREFERENCE_USE_JS', '     JavaScript ?');
@define('PREFERENCE_USE_JS_DESC', '      JavaScript,    Serendipity     .          drag-and-drop    .');

@define('PREFERENCE_USE_JS_WARNING', '(   JavaScript.   ,      JavaScript       JavaScript  .)');


@define('INSTALL_PERMALINK_COMMENTSPATH', '  ');
@define('PERM_SET_CHILD', '      ');
@define('PERMISSION_FORBIDDEN_PLUGINS', ' ');
@define('PERMISSION_FORBIDDEN_HOOKS', ' ');
@define('PERMISSION_FORBIDDEN_ENABLE', '  Plugin ACL    ?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', '  "Plugin ACL   "  ,                .');
@define('DELETE_SELECTED_ENTRIES', '   ');
@define('PLUGIN_AUTHORS_MINCOUNT', '     - X ');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
